==> custom_theme-0.0.1.tar.gz: example/lib/my_themes.dart <==
import 'package:custom_theme/custom_theme.dart';
import 'package:flutter/material.dart';

class MyData {
  MyData({
    this.squareColor = Colors.greenAccent,
    this.size = 100,
    this.text = "Theme1",
  });

  final Color squareColor;

  final double size;

  final String text;
}

MyData getMyData(BuildContext context) =>
    CustomTheme.of(context).userData as MyData;

class LightTheme1 extends CustomTheme {
  LightTheme1()
      : super(
          themeData: ThemeData.light().copyWith(
              primaryColor: Colors.pink[300],
              accentColor: Colors.yellow,
              floatingActionButtonTheme: ThemeData.light()
                  .floatingActionButtonTheme
                  .copyWith(backgroundColor: Colors.yellow)),
          userData: MyData(),
        );
}

class LightTheme2 extends CustomTheme {
  LightTheme2()
      : super(
          themeData: ThemeData.light().copyWith(
            primaryColor: Colors.green[300],
            textTheme: ThemeData.light().textTheme.copyWith(
                  body1: ThemeData.light().textTheme.body1.copyWith(
                        fontSize: 50,
                      ),
                ),
          ),
          userData: MyData(
            text: "Theme2",
            squareColor: Colors.indigoAccent[100],
            size: 150,
          ),
        );
}

class DarkTheme extends CustomTheme {
  DarkTheme()
      : super(
          themeData: ThemeData.dark().copyWith(
            primaryColor: Colors.purple,
            textTheme: ThemeData.dark().textTheme.copyWith(
                  body1: ThemeData.dark().textTheme.body1.copyWith(
                        color: Colors.cyan,
                      ),
                ),
          ),
          userData: MyData(
            text: "Dark",
            squareColor: Colors.pink[200],
            size: 80,
          ),
        );
}

==> custom_theme-1.9.1.tar.gz: example/lib/my_themes.dart <==
import 'package:custom_theme/custom_theme.dart';
import 'package:flutter/material.dart';

class MyData {
  MyData({
    this.squareColor = Colors.greenAccent,
    this.size = 100,
    this.text = "Theme1",
    this.duration = const Duration(milliseconds: 300),
  });

  final Color squareColor;

  final double size;

  final String text;

  final Duration duration;
}

class LightTheme1 extends CustomTheme<MyData> {
  LightTheme1()
      : super(
          themeData: ThemeData.light().copyWith(
              primaryColor: Colors.pink[300],
              accentColor: Colors.yellow,
              floatingActionButtonTheme: ThemeData.light()
                  .floatingActionButtonTheme
                  .copyWith(backgroundColor: Colors.yellow)),
          userData: MyData(),
        );
}

class LightTheme2 extends CustomTheme<MyData> {
  LightTheme2()
      : super(
          themeData: ThemeData.light().copyWith(
            primaryColor: Colors.green[300],
            textTheme: ThemeData.light().textTheme.copyWith(
                  body1: ThemeData.light().textTheme.body1.copyWith(
                        fontSize: 50,
                      ),
                ),
          ),
          userData: MyData(
            text: "Theme2",
            squareColor: Colors.indigoAccent[100],
            size: 150,
          ),
        );
}

class DarkTheme extends CustomTheme<MyData> {
  DarkTheme()
      : super(
          themeData: ThemeData.dark().copyWith(
            primaryColor: Colors.purple,
            textTheme: ThemeData.dark().textTheme.copyWith(
                  body1: ThemeData.dark().textTheme.body1.copyWith(
                        color: Colors.cyan,
                      ),
                ),
          ),
          userData: MyData(
            text: "Dark",
            squareColor: Colors.pink[200],
            size: 80,
            duration: const Duration(milliseconds: 800),
          ),
        );
}
